/// Sugar for \part{} creation
#[macro_export]
macro_rules! part {
    ($i:literal) => {
        Component::Part(Part::new($i))
    };
}

/// Sugar for \chapter{} creation
#[macro_export]
macro_rules! chapter {
    ($i:literal) => {
        Component::Chapter(Chapter::new($i))
    };
}

/// Sugar for \section{} creation
#[macro_export]
macro_rules! section {
    ($i:literal) => {
        Component::Section(Section::new($i))
    };
}

/// Sugar for environment creation. 
#[macro_export]
macro_rules! environment {
    ($i:literal) => {
        Component::Environment(Environment::new($i))
    };
}

/// This could've gotten real ugly if you had to do it yourself
/// So whenever you've got a latex macro you defined earlier, and want to use it, use this macro.
/// ```rust
/// command!(<your document variable>, "<your command/macro name>", <appropriate arguments to the command>)
/// ```
#[macro_export]
macro_rules! command {
    ($doc:ident, $cmd:literal, $( $x:expr ),*) => {
        Component::Command($doc.get_command($cmd)?.call(vec![$($x, )*])?)
    };
}

/// Sugar for document creation
#[macro_export]
macro_rules! document {
    ($l:literal) => {
        Document::new(DocumentClass::new($l))
    };
}

/// This, too, could've gotten ugly.
/// Package creation with options.
/// ```rust
/// package!("<package name>", <whatever options you want, as literals>)
/// ```
#[macro_export]
macro_rules! package {
    ($pkg:literal, $( $opt:literal ),*) => {{
        let mut package = Package::new($pkg);
        $(package.add_option($opt);)*
        package
    }};
}
